@@ -655,9 +655,9 @@ class RemoteBluetoothDevicePairing(RemoteBluetoothDeviceRecord):
     # --- end of api mimic methods ---
 
     @classmethod
-    def __count(klass, remote, state=None):
+    def _count(klass, remote, state=None):
         qs = klass.objects.all()
-        if state:
+        if state is not None:
             qs=qs.filter(state=state)
         if isinstance(remote, str) or isinstance(remote, unicode):
             return qs.filter(remote__address=remote)
@@ -667,29 +667,29 @@ class RemoteBluetoothDevicePairing(RemoteBluetoothDeviceRecord):
     @classmethod
     def isPaired(klass, remote):
         logger.debug("isPaired %s" % remote )
-        return klass.__count(remote, klass.PAIRED).count() > 0
+        return klass._count(remote, klass.PAIRED).count() > 0
     
     @classmethod
     def rejectedCount(klass, remote):
         logger.debug("rejectedCount %s" % remote)
-        return klass.__count(remote=remote, state=klass.REJECTED).count()
+        return klass._count(remote=remote, state=klass.REJECTED).count()
 
     @classmethod
     def timeoutCount(klass, remote):
         logger.debug("timeoutCount %s" % remote)
-        return klass.__count(remote=remote, state=klass.TIMEOUT).count()
+        return klass._count(remote=remote, state=klass.TIMEOUT).count()
 
     @classmethod
     def triesCount(klass, remote):
         logger.debug("triesCount %s" % remote)
-        return klass.__count(remote=remote).count()
+        return klass._count(remote=remote).count()
 
     @classmethod
     def getDonglesForRemote(klass, remote):
         logger.debug("getDonglesForRemote %s" % remote)
 
         return [ a['dongle__address'] for a in 
-            klass.__count(remote=remote).values('dongle__address') ]
+            klass._count(remote=remote).values('dongle__address') ]
 
 STATES = dict([(a[1], a[0]) for a in PAIRING])
 RemoteBluetoothDevicePairing.STATES = STATES
